use crate::frontend::int_program::BfInstruction;

pub fn merge_instructions(_a: &BfInstruction, _b: &BfInstruction) -> Option<BfInstruction> {
    None
}


pub fn collapse_loop(_l: &[BfInstruction]) -> Option<BfInstruction> {
    None
}
